@@ -26,16 +26,16 @@
 FAiRLib <- dirname(system.file(package = "FAiR"))
 version <- packageDescription("FAiR", lib.loc = FAiRLib)$Version
 BuildDate <- packageDescription("FAiR", lib.loc = FAiRLib)$Date
-cat(paste("\n##  FAiR Version", version, "Build Date:", BuildDate, "\n"))
-cat("## See http://wiki.r-project.org/rwiki/doku.php?id=packages:cran:fair for more info")
-cat("\nFAiR  Copyright (C) 2008  Benjamin King Goodrich\n")
-cat("This program comes with ABSOLUTELY NO WARRANTY.\n")
-cat("This is free software, and you are welcome to redistribute it\n")
-cat("under certain conditions, namely those specified in the LICENSE file\n")
-cat("in the root directory of the source code.\n")
+packageStartupMessage(paste("##  FAiR Version", version, "Build Date:", BuildDate))
+packageStartupMessage("## See http://wiki.r-project.org/rwiki/doku.php?id=packages:cran:fair for more info")
+packageStartupMessage("FAiR  Copyright (C) 2008  Benjamin King Goodrich")
+packageStartupMessage("This program comes with ABSOLUTELY NO WARRANTY.")
+packageStartupMessage("This is free software, and you are welcome to redistribute it")
+packageStartupMessage("under certain conditions, namely those specified in the LICENSE file")
+packageStartupMessage("in the root directory of the source code.")
 
 if (length(grep("darwin", R.version$platform))) {
-	cat("\n\nWARNING: It appears you are using a Mac.\n",
+  packageStartupMessage("\n\nWARNING: It appears you are using a Mac.\n",
 	"FAiR will CRASH under normal usage unless the X server is running.\n",
 	"If you are using the R GUI, click the X icon in the top middle ",
 	"region of the GUI and then restart the R GUI.\n",
@@ -47,20 +47,13 @@ if (length(grep("darwin", R.version$platform))) {
 
 else if (.Platform$OS.type == "windows") {
 	flush.console()
-	cat("\n\n It appears you are using Windows.\n",
+	packageStartupMessage("\n\n It appears you are using Windows.\n",
 	    "It is recommended that you disable buffering by pressing Ctrl-W or\n",
 	    "by deselecting Misc -> Buffered output in the menu at the top.\n",
 	    "Doing so will consistently print the progress of the genetic algorithm.\n")
 	flush.console()
 }
 
-## Initialize jit if installed
-if(!require(jit)) {
-	jit <<- function (f) return(NULL)
-	warning("You can ignore the adjacent warning message about jit, although FAiR",
-		" will run slightly faster if you install Ra and jit")
-}
-
 ## Hack to run on R < 2.6.0 (maybe not necessary anymore)
 if( (as.numeric(R.version$minor) < 6.0) | (as.numeric(R.version$minor) < 2) ) {
 	warning("FAiR is not tested on this version of R but may work sufficiently.\n",
